@@ -1,11 +1,13 @@
 // Copyright 2020-2022 PANDA GmbH
 
-#ifndef SRC_WAVELET_TYPE_H_
-#define SRC_WAVELET_TYPE_H_
+#ifndef PYTHON_SRC_WAVELET_PARAMETERS_H_
+#define PYTHON_SRC_WAVELET_PARAMETERS_H_
 
 #include <pybind11/pybind11.h>
 #include <wavelet_buffer/wavelet_parameters.h>
 
+#include <string>
+
 namespace py = pybind11;
 
 std::string WaveletTypeRepr(drift::WaveletTypes value);
@@ -14,4 +16,4 @@ std::string WaveletParametersRepr(const std::string &class_name,
 void WrapWaveletType(py::module *m);
 void WrapWaveletParameters(py::module *m);
 
-#endif  // SRC_WAVELET_TYPE_H_
+#endif  // PYTHON_SRC_WAVELET_PARAMETERS_H_
